@@ -102,6 +102,9 @@ update_log (const gchar *message)
 	struct tm *t;
 	time_t seconds;
 	
+	if (!message)
+		return;
+	
 	log = fopen (LOG_FILE, "a+");
 	if (!log)
 		return;
@@ -110,7 +113,11 @@ update_log (const gchar *message)
 	t = gmtime (&seconds);
 	strftime (time_string, 64, "%c", t);
 	
-	formatted_mesg = g_strdup_printf ("%s: %s", time_string, message);
+	if (message [strlen (message) - 1] != '\n')
+		formatted_mesg = g_strdup_printf ("%s: %s\n", time_string, message);
+	else
+		formatted_mesg = g_strdup_printf ("%s: %s", time_string, message);
+	
 	fwrite (formatted_mesg, sizeof (gchar), strlen (formatted_mesg), log);
 	
 	fclose (log);
@@ -155,7 +162,7 @@ package_disliked (const gchar *package)
 	gchar **lines;
 	gint i;
 	
-	if (g_file_get_contents ("/root/.dropline/cache_dir", &cache_dir, NULL, NULL))
+	if (g_file_get_contents ("/etc/dropline/cache_dir", &cache_dir, NULL, NULL))
 	{
 		newline = strstr (cache_dir, "\n");
 		if (newline)
@@ -192,27 +199,25 @@ package_blacklisted (const gchar *package)
 	gchar *blacklist_file, *blacklist_packs;
 	gchar **lines;
 	gint i;
-/*	
-	if (g_file_get_contents ("/root/.dropline/cache_dir", &cache_dir, NULL, NULL))
-	{
-		newline = strstr (cache_dir, "\n");
-		if (newline)
-			cache_dir [newline - cache_dir] = '\0';
-		
-	}
-	else
-		cache_dir = g_strdup ("/var/cache/dropline-installer");
-*/	
-	blacklist_file = g_strdup ("/root/.dropline/blacklist");
+	
+	blacklist_file = g_strdup ("/etc/dropline/blacklist");
 	
 	if (g_file_get_contents (blacklist_file, &blacklist_packs, NULL, NULL))
 	{
 		retval = FALSE;
 		lines = g_strsplit (blacklist_packs, "\n", MAX_FILES);
+		
 		for (i = 0; lines [i] && lines [i][0] != '\0' && !retval; i++)
 		{
+			gchar *msg;
+			
+			msg = g_strdup_printf ("blacklist line[%d]: %s\n", i, lines[i]);
+			update_log (msg);
+			
 			if (!strncmp (lines [i], package, strlen (lines [i])))
 				retval = TRUE;
+
+			g_free (msg);
 		}
 		
 		g_strfreev (lines);
@@ -281,10 +286,8 @@ update_parse (DroplineData *data, const gchar *mesg)
 			{
 				colon = g_strrstr (lines [i], ".");
 				update_log (colon);
-				update_log ("\n");
 				lines [i][colon - lines[i] - 2] = '\0';
 				update_log (lines[i]);
-				update_log ("\n");
 				if (!package_disliked (lines [i]) &&
 					!package_blacklisted (lines [i]))
 				{
